-----------------------------------------------------------------------------------------------
-- Client Lua Script for HideBuffs
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- HideBuffs Module Definition
-----------------------------------------------------------------------------------------------
local HideBuffs = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function HideBuffs:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function HideBuffs:Init()
	self.showBuffs = false
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- HideBuffs OnLoad
-----------------------------------------------------------------------------------------------
function HideBuffs:OnLoad()
	Apollo.RegisterTimerHandler("OneSecTimer", "OnTimer", self)
	Apollo.RegisterSlashCommand("hidebuffs", "OnHideBuffsOn", self)
end

-----------------------------------------------------------------------------------------------
-- HideBuffs Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/hidebuffs"
function HideBuffs:OnHideBuffsOn()
	self.showBuffs = not self.showBuffs 
end

-- on timer
function HideBuffs:OnTimer()
	-- Do your timer-related stuff here.
	-- Safely dig into the GUI elements
	local addonTargetFrame = Apollo.GetAddon("TargetFrame")
	if addonTargetFrame == nil then return end
	
	local luaUnitFrame = addonTargetFrame.luaUnitFrame
	if luaUnitFrame == nil then return end
	self:HideGuildBuffs(luaUnitFrame)
	
	local luaTargetFrame = addonTargetFrame.luaTargetFrame
	if luaTargetFrame == nil then return end
	self:HideGuildBuffs(luaTargetFrame)
	
	local luaFocusFrame = addonTargetFrame.luaFocusFrame
	if luaFocusFrame == null then return end
	self:HideGuildBuffs(luaFocusFrame)
end

function HideBuffs:HideGuildBuffs(luaFrame)
	local wndMainClusterFrame = luaFrame.wndMainClusterFrame
	if wndMainClusterFrame == nil then return end
	
	local wndBeneBuffBar = wndMainClusterFrame:FindChild("BeneBuffBar")
	if wndBeneBuffBar == nil then return end
	
	local buffs = wndBeneBuffBar:GetChildren()
	if buffs == nil then return end
	
	-- Buffs found, loop over them all
	for _,buff in ipairs(buffs) do
		local tooltip = buff:GetBuffTooltip()
		if string.match(tooltip, "guild") or string.match(tooltip, "XP, Renown") then
			buff:Show(self.showBuffs, true)
		end
	end
end


-----------------------------------------------------------------------------------------------
-- HideBuffs Instance
-----------------------------------------------------------------------------------------------
local HideBuffsInst = HideBuffs:new()
HideBuffsInst:Init()
